workflowdeployments

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

func NewClient

func NewClient(opts ...option.RequestOption) *Client

func (*Client) List

Used to list all Workflow Deployments.

func (*Client) ListWorkflowReleaseTags added in v0.9.5

List Release Tags associated with the specified Workflow Deployment

func (*Client) Retrieve added in v0.3.8

Used to retrieve a workflow deployment given its ID or name.

func (*Client) RetrieveWorkflowReleaseTag added in v0.6.2

func (c *Client) RetrieveWorkflowReleaseTag(
	ctx context.Context,

	id string,

	name string,
	opts ...option.RequestOption,
) (*vellumclientgo.WorkflowReleaseTagRead, error)

Retrieve a Workflow Release Tag by tag name, associated with a specified Workflow Deployment.

func (*Client) UpdateWorkflowReleaseTag added in v0.6.2

Updates an existing Release Tag associated with the specified Workflow Deployment.

func (*Client) WorkflowDeploymentEventExecution added in v0.14.23

func (c *Client) WorkflowDeploymentEventExecution(
	ctx context.Context,
	executionId string,
	id string,
	opts ...option.RequestOption,
) (*vellumclientgo.WorkflowEventExecutionRead, error)

func (*Client) WorkflowDeploymentHistoryItemRetrieve added in v0.10.1

func (c *Client) WorkflowDeploymentHistoryItemRetrieve(
	ctx context.Context,

	historyIdOrReleaseTag string,

	id string,
	opts ...option.RequestOption,
) (*vellumclientgo.WorkflowDeploymentHistoryItem, error)

DEPRECATED: This endpoint is deprecated and will be removed in a future release. Please use the `retrieve_workflow_deployment_release` endpoint instead.

Jump to