Documentation
¶
Index ¶
- type Client
- func (c *Client) List(ctx context.Context, request *vellumclientgo.WorkflowDeploymentsListRequest, ...) (*vellumclientgo.PaginatedSlimWorkflowDeploymentList, error)
- func (c *Client) ListWorkflowDeploymentEventExecutions(ctx context.Context, id string, ...) (*vellumclientgo.WorkflowDeploymentEventExecutionsResponse, error)
- func (c *Client) ListWorkflowReleaseTags(ctx context.Context, id string, ...) (*vellumclientgo.PaginatedWorkflowReleaseTagReadList, error)
- func (c *Client) Retrieve(ctx context.Context, id string, opts ...option.RequestOption) (*vellumclientgo.WorkflowDeploymentRead, error)
- func (c *Client) RetrieveWorkflowReleaseTag(ctx context.Context, id string, name string, opts ...option.RequestOption) (*vellumclientgo.WorkflowReleaseTagRead, error)
- func (c *Client) UpdateWorkflowReleaseTag(ctx context.Context, id string, name string, ...) (*vellumclientgo.WorkflowReleaseTagRead, error)
- func (c *Client) WorkflowDeploymentEventExecution(ctx context.Context, executionId string, id string, ...) (*vellumclientgo.WorkflowEventExecutionRead, error)
- func (c *Client) WorkflowDeploymentHistoryItemRetrieve(ctx context.Context, historyIdOrReleaseTag string, id string, ...) (*vellumclientgo.WorkflowDeploymentHistoryItem, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func NewClient ¶
func NewClient(opts ...option.RequestOption) *Client
func (*Client) List ¶
func (c *Client) List( ctx context.Context, request *vellumclientgo.WorkflowDeploymentsListRequest, opts ...option.RequestOption, ) (*vellumclientgo.PaginatedSlimWorkflowDeploymentList, error)
Used to list all Workflow Deployments.
func (*Client) ListWorkflowDeploymentEventExecutions ¶ added in v0.14.23
func (c *Client) ListWorkflowDeploymentEventExecutions( ctx context.Context, id string, request *vellumclientgo.ListWorkflowDeploymentEventExecutionsRequest, opts ...option.RequestOption, ) (*vellumclientgo.WorkflowDeploymentEventExecutionsResponse, error)
func (*Client) ListWorkflowReleaseTags ¶ added in v0.9.5
func (c *Client) ListWorkflowReleaseTags( ctx context.Context, id string, request *vellumclientgo.ListWorkflowReleaseTagsRequest, opts ...option.RequestOption, ) (*vellumclientgo.PaginatedWorkflowReleaseTagReadList, error)
List Release Tags associated with the specified Workflow Deployment
func (*Client) Retrieve ¶ added in v0.3.8
func (c *Client) Retrieve( ctx context.Context, id string, opts ...option.RequestOption, ) (*vellumclientgo.WorkflowDeploymentRead, error)
Used to retrieve a workflow deployment given its ID or name.
func (*Client) RetrieveWorkflowReleaseTag ¶ added in v0.6.2
func (c *Client) RetrieveWorkflowReleaseTag( ctx context.Context, id string, name string, opts ...option.RequestOption, ) (*vellumclientgo.WorkflowReleaseTagRead, error)
Retrieve a Workflow Release Tag by tag name, associated with a specified Workflow Deployment.
func (*Client) UpdateWorkflowReleaseTag ¶ added in v0.6.2
func (c *Client) UpdateWorkflowReleaseTag( ctx context.Context, id string, name string, request *vellumclientgo.PatchedWorkflowReleaseTagUpdateRequest, opts ...option.RequestOption, ) (*vellumclientgo.WorkflowReleaseTagRead, error)
Updates an existing Release Tag associated with the specified Workflow Deployment.
func (*Client) WorkflowDeploymentEventExecution ¶ added in v0.14.23
func (c *Client) WorkflowDeploymentEventExecution( ctx context.Context, executionId string, id string, opts ...option.RequestOption, ) (*vellumclientgo.WorkflowEventExecutionRead, error)
func (*Client) WorkflowDeploymentHistoryItemRetrieve ¶ added in v0.10.1
func (c *Client) WorkflowDeploymentHistoryItemRetrieve( ctx context.Context, historyIdOrReleaseTag string, id string, opts ...option.RequestOption, ) (*vellumclientgo.WorkflowDeploymentHistoryItem, error)
DEPRECATED: This endpoint is deprecated and will be removed in a future release. Please use the `retrieve_workflow_deployment_release` endpoint instead.
Click to show internal directories.
Click to hide internal directories.